==> haskell-lens-aeson-1.0.2-135-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-lens-aeson.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: lens-aeson
version: 1.0.2
id: lens-aeson-1.0.2-iicRPBbEVGJ9nyRGKTqVU
key: lens-aeson-1.0.2-iicRPBbEVGJ9nyRGKTqVU
license: MIT
copyright: Copyright (C) 2012 Paul Wilson
           Copyright (C) 2013 Edward A. Kmett
maintainer: Edward A. Kmett <ekmett@gmail.com>
author: Edward A. Kmett
stability: provisional
homepage: http://github.com/lens/lens-aeson/
synopsis: Law-abiding lenses for aeson
description:
    Law-abiding lenses for aeson
category: Numeric
abi: b8ab0eb6999253dc6a960dc85d0e2f89
exposed: True
exposed-modules:
    Data.Aeson.Lens
import-dirs: /usr/lib/ghc-8.6.5/site-local/lens-aeson-1.0.2
library-dirs: /usr/lib/ghc-8.6.5/site-local/lens-aeson-1.0.2
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.6.5/lens-aeson-1.0.2
hs-libraries: HSlens-aeson-1.0.2-iicRPBbEVGJ9nyRGKTqVU
depends:
    aeson-1.4.3.0-2f2DWYxbnUnFm9iFQHaKmb
    attoparsec-0.13.2.2-1slbQhZI8n0L2sAfK4cuOg base-4.12.0.0
    bytestring-0.10.8.2 lens-4.17.1-L7DHqflYde2JbmoGM5Kz62
    scientific-0.3.6.2-L1dtV0bHm4E7J1We1UVw6b text-1.2.3.1
    unordered-containers-0.2.10.0-5bnYBnE7Vkj9Kd62fWith8
    vector-0.12.0.3-2LEYu9M2i7lERDtz76XG3n
haddock-interfaces: /usr/share/doc/haskell-lens-aeson/html/lens-aeson.haddock
haddock-html: /usr/share/doc/haskell-lens-aeson/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-lens-aeson-1.0.2-140-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-lens-aeson.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: lens-aeson
version: 1.0.2
id: lens-aeson-1.0.2-Kxk3SfsIKGtFHB47imzSgS
key: lens-aeson-1.0.2-Kxk3SfsIKGtFHB47imzSgS
license: MIT
copyright: Copyright (C) 2012 Paul Wilson
           Copyright (C) 2013 Edward A. Kmett
maintainer: Edward A. Kmett <ekmett@gmail.com>
author: Edward A. Kmett
stability: provisional
homepage: http://github.com/lens/lens-aeson/
synopsis: Law-abiding lenses for aeson
description:
    Law-abiding lenses for aeson
category: Numeric
abi: 2ccbe14e8e40cfb6bab9b0d42a32426f
exposed: True
exposed-modules:
    Data.Aeson.Lens
import-dirs: /usr/lib/ghc-8.6.5/site-local/lens-aeson-1.0.2
library-dirs: /usr/lib/ghc-8.6.5/site-local/lens-aeson-1.0.2
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.6.5/lens-aeson-1.0.2
hs-libraries: HSlens-aeson-1.0.2-Kxk3SfsIKGtFHB47imzSgS
depends:
    aeson-1.4.3.0-5u6hknCeN6OEP5DlN5W0LL
    attoparsec-0.13.2.2-FR6Av5BO2dBDiw4NtrzSsH base-4.12.0.0
    bytestring-0.10.8.2 lens-4.17.1-Ii3Qh0jlmopECfPGkUKRMA
    scientific-0.3.6.2-L1dtV0bHm4E7J1We1UVw6b text-1.2.3.1
    unordered-containers-0.2.10.0-KN3bhnJnJVDChkuCyIQcSr
    vector-0.12.0.3-2LEYu9M2i7lERDtz76XG3n
haddock-interfaces: /usr/share/doc/haskell-lens-aeson/html/lens-aeson.haddock
haddock-html: /usr/share/doc/haskell-lens-aeson/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
